import '@/styles/globals.css';
import { GeistSans } from 'geist/font/sans';
import { cn } from '@/lib/utils';
import { ThemeProvider } from '@/components/context/Theme';
import { TVModeProvider } from '@/components/context/TVMode';
import { AuthProvider } from '@/components/context/Auth'
import LoginForm from '@/components/auth/LoginForm';
import Header from '@/components/defaults/Header';

import { type Metadata } from 'next';
export const metadata: Metadata = {
  title: 'Tech Tracker',
  description:
    'App used by COG IT employees to \
    update their status throughout the day.',
  icons: [
    {
      rel: 'icon',
      url: '/favicon.ico',
    },
    {
      rel: 'icon',
      type: 'image/png',
      sizes: '32x32',
      url: '/images/tech_tracker_favicon.png',
    },
    {
      rel: 'apple-touch-icon',
      url: '/imges/tech_tracker_appicon.png',
    },
  ],
};

const RootLayout = async ({
  children,
}: Readonly<{ children: React.ReactNode }>) => {
  return (
    <html
      lang='en'
      className={`${GeistSans.variable}`}
      suppressHydrationWarning
    >
      <body className={cn('min-h-screen bg-background font-sans antialiased')}>
        <ThemeProvider
          attribute='class'
          defaultTheme='system'
          enableSystem
          disableTransitionOnChange
        >
          <TVModeProvider>
            <AuthProvider>
              <main className='min-h-screen'>
                <Header />
                {children}
              </main>
            </AuthProvider>
          </TVModeProvider>
        </ThemeProvider>
      </body>
    </html>
  );
};
export default RootLayout;
