'use client';

import { useState, useEffect } from 'react';
import Image from 'next/image';
import { useRouter } from 'next/navigation';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuLabel,
  DropdownMenuItem,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from '@/components/ui/dropdown-menu';
import { Button } from '@/components/ui/button';
import { getImageUrl } from '@/server/actions/image';
import { useAuth } from '@/components/context/Auth';

const AvatarDropdown = () => {
  const router = useRouter();
  const { user, signOut } = useAuth();
  const [pfp, setPfp] = useState<string>('/images/default_user_pfp.png');
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const downloadImage = async (path: string) => {
      try {
        setLoading(true);
        const url = await getImageUrl('avatars', path);
        console.log(url);
        setPfp(url);
      } catch (error) {
        console.error(
          'Error downloading image:',
          error instanceof Error ? error.message : error,
        );
      } finally {
        setLoading(false);
      } 
    };
    if (user?.avatar_url) {
      try {
        downloadImage(user.avatar_url).catch((error) => {
          console.error('Error downloading image:', error);
        });
      } catch (error) {
        console.error('Error: ', error);
      }
    }
  }, [user]);

  const getInitials = (fullName: string | undefined): string => {
    if (!fullName || fullName.trim() === '' || fullName === 'undefined')
      return 'NA';
    const nameParts = fullName.trim().split(' ');
    const firstInitial = nameParts[0]?.charAt(0).toUpperCase() ?? 'N';
    if (nameParts.length === 1) return 'NA';
    const lastIntitial =
      nameParts[nameParts.length - 1]?.charAt(0).toUpperCase() ?? 'A';
    return firstInitial + lastIntitial;
  };

  // Handle sign out
  const handleSignOut = async () => {
    await signOut();
    router.push('/');
  };

  // Show nothing while loading
  if (loading) {
    return <div className='animate-pulse h-8 w-8 rounded-full bg-gray-300' />;
  }

  // If no session, return empty div
  if (!session) return <div />;
  return (
    <div className='m-auto mt-1'>
      <DropdownMenu>
        <DropdownMenuTrigger>
          <Image
            src={pfp}
            alt={getInitials(user?.full_name) ?? 'NA'}
            width={40}
            height={40}
            className='rounded-full border-2
              border-muted-foreground m-auto mr-1 md:mr-2
              max-w-[35px] sm:max-w-[40px]'
          />
        </DropdownMenuTrigger>
        <DropdownMenuContent>
          <DropdownMenuLabel>{user?.full_name}</DropdownMenuLabel>
          <DropdownMenuSeparator />
          <DropdownMenuItem asChild>
            <Button onClick={handleSignOut} className='w-full text-left'>
              Sign Out
            </Button>
          </DropdownMenuItem>
        </DropdownMenuContent>
      </DropdownMenu>
    </div>
  );
};
export default AvatarDropdown;
